FlvTagHeader

Struct FlvTagHeader 

pub struct FlvTagHeader {
    pub tag_type: FlvTagType,
    pub data_size: u32,
    pub timestamp: u32,
    pub stream_id: u32,
}
The tag header part of FLV tag.

Fields

tag_type: FlvTagType

Reserved 2 bits Reserved for FMS, should be 0. Filter 1 bit Indicates if packets are filtered. 0 = No pre-processing required 1 = Pre-processing (Such as decryption) of the packet is required before it can be rendered. TagType 5 bits The type of contents in this tag, 8 = audio, 9 = video, 18 = script.

data_size: u32

The size of the tag’s data part, 3 bytes.

timestamp: u32

The timestamp (in milliseconds) of the tag, Timestamp (3 bytes) + TimestampExtended (1 byte).

stream_id: u32

The id of stream is always 0, 3 bytes.